@@ -234,7 +234,7 @@ sc_display_update_texture(struct sc_display *display, const AVFrame *frame) {
 
 enum sc_display_result
 sc_display_render(struct sc_display *display, const SDL_Rect *geometry,
-                  unsigned rotation) {
+                  enum sc_orientation orientation) {
     SDL_RenderClear(display->renderer);
 
     if (display->pending.flags) {
@@ -247,33 +247,33 @@ sc_display_render(struct sc_display *display, const SDL_Rect *geometry,
     SDL_Renderer *renderer = display->renderer;
     SDL_Texture *texture = display->texture;
 
-    if (rotation == 0) {
+    if (orientation == SC_ORIENTATION_0) {
         int ret = SDL_RenderCopy(renderer, texture, NULL, geometry);
         if (ret) {
             LOGE("Could not render texture: %s", SDL_GetError());
             return SC_DISPLAY_RESULT_ERROR;
         }
     } else {
-        // rotation in RenderCopyEx() is clockwise, while screen->rotation is
-        // counterclockwise (to be consistent with --lock-video-orientation)
-        int cw_rotation = (4 - rotation) % 4;
+        unsigned cw_rotation = sc_orientation_get_rotation(orientation);
         double angle = 90 * cw_rotation;
 
         const SDL_Rect *dstrect = NULL;
         SDL_Rect rect;
-        if (rotation & 1) {
+        if (sc_orientation_is_swap(orientation)) {
             rect.x = geometry->x + (geometry->w - geometry->h) / 2;
             rect.y = geometry->y + (geometry->h - geometry->w) / 2;
             rect.w = geometry->h;
             rect.h = geometry->w;
             dstrect = &rect;
         } else {
-            assert(rotation == 2);
             dstrect = geometry;
         }
 
+        SDL_RendererFlip flip = sc_orientation_is_mirror(orientation)
+                              ? SDL_FLIP_HORIZONTAL : 0;
+
         int ret = SDL_RenderCopyEx(renderer, texture, NULL, dstrect, angle,
-                                   NULL, 0);
+                                   NULL, flip);
         if (ret) {
             LOGE("Could not render texture: %s", SDL_GetError());
             return SC_DISPLAY_RESULT_ERROR;
