@@ -6,6 +6,8 @@ public final class DeviceMessageSender {
 
     private final DesktopConnection connection;
 
+    private Thread thread;
+
     private String clipboardText;
 
     private long ack;
@@ -24,8 +26,8 @@ public final class DeviceMessageSender {
         notify();
     }
 
-    public void loop() throws IOException, InterruptedException {
-        while (true) {
+    private void loop() throws IOException, InterruptedException {
+        while (!Thread.currentThread().isInterrupted()) {
             String text;
             long sequence;
             synchronized (this) {
@@ -49,4 +51,29 @@ public final class DeviceMessageSender {
             }
         }
     }
+
+    public void start() {
+        thread = new Thread(() -> {
+            try {
+                loop();
+            } catch (IOException | InterruptedException e) {
+                // this is expected on close
+            } finally {
+                Ln.d("Device message sender stopped");
+            }
+        }, "control-send");
+        thread.start();
+    }
+
+    public void stop() {
+        if (thread != null) {
+            thread.interrupt();
+        }
+    }
+
+    public void join() throws InterruptedException {
+        if (thread != null) {
+            thread.join();
+        }
+    }
 }
